==> haskell-stm-containers-1.2.0.3-27-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-containers
version:              1.2.0.3
visibility:           public
id:                   stm-containers-1.2.0.3-1iDLVR51EHg5hAxeIwDw4A
key:                  stm-containers-1.2.0.3-1iDLVR51EHg5hAxeIwDw4A
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  fad1ee2cbde4af1f3b6a6ed8c7ca0a2d
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-containers-1.2.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-containers-1.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.0.3-1iDLVR51EHg5hAxeIwDw4A
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-BZ1SDhVcYQg5tbmHE6HpOo
    focus-1.0.3.2-AKC1YexAFjH6ZbwqCay7au
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    list-t-1.0.5.4-F3DLF2fJQIg5JN1yChcuYQ
    stm-hamt-1.2.0.14-JBqB2K3bYYKGsPZBFgSTb3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.0.3-30-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-containers
version:              1.2.0.3
visibility:           public
id:                   stm-containers-1.2.0.3-BbkvAZsPY142eqsNz94NNo
key:                  stm-containers-1.2.0.3-BbkvAZsPY142eqsNz94NNo
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  82c51fd54ed1d5051ecb5a4b2b0423fd
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-containers-1.2.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-containers-1.2.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.0.3-BbkvAZsPY142eqsNz94NNo
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-K23AdopIRO573cyM3y2lzg
    focus-1.0.3.2-7bZddhb5A75J96N1tz4wkO
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    list-t-1.0.5.4-67qwCDNovSAEGvQSaLO2H9
    stm-hamt-1.2.0.14-GdLrvnxcCVJ5tda9frfskL transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
